summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--include/ap_socache.h12
-rw-r--r--modules/ssl/ssl_scache.c2
2 files changed, 11 insertions, 3 deletions
diff --git a/modules/ssl/ssl_scache.c b/modules/ssl/ssl_scache.c
index 83e40053ac..7148cd9104 100644
--- a/modules/ssl/ssl_scache.c
+++ b/modules/ssl/ssl_scache.c
@@ -161,7 +161,7 @@ void ssl_scache_remove(server_rec *s, UCHAR *id, int idlen,
ssl_mutex_on(s);
}
- mc->sesscache->delete(mc->sesscache_context, s, id, idlen, p);
+ mc->sesscache->remove(mc->sesscache_context, s, id, idlen, p);
if (mc->sesscache->flags & AP_SOCACHE_FLAG_NOTMPSAFE) {
ssl_mutex_off(s);
diff --git a/include/ap_socache.h b/include/ap_socache.h
index 8d0492e34d..d87ce76d29 100644
--- a/include/ap_socache.h
+++ b/include/ap_socache.h
@@ -30,7 +30,11 @@
#include "ap_provider.h"
#include "apr_pools.h"
-/** If this flag is set, the store/retrieve/delete/status interfaces
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+/** If this flag is set, the store/retrieve/remove/status interfaces
* of the provider are NOT safe to be called concurrently from
* multiple processes or threads, and an external global mutex must be
* used to serialize access to the provider. */
@@ -141,7 +145,7 @@ typedef struct ap_socache_provider_t {
* @param idlen Length of id blob
* @param pool Pool for temporary allocations.
*/
- void (*delete)(ap_socache_instance_t *instance, server_rec *s,
+ void (*remove)(ap_socache_instance_t *instance, server_rec *s,
const unsigned char *id, unsigned int idlen,
apr_pool_t *pool);
@@ -163,5 +167,9 @@ typedef struct ap_socache_provider_t {
/** Default provider name. */
#define AP_SOCACHE_DEFAULT_PROVIDER "default"
+#ifdef __cplusplus
+}
+#endif
+
#endif /* AP_SOCACHE_H */
/** @} */